==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/es_PR.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Asistente de Ejecución Inicial",
    "Add your profile information! For example your email is needed to reset your password." : "¡Agregua tu información de perfil! Por ejemplo tu correo electrónico es necesario para restablecer tu contraseña.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "¡Agregua tu información de perfil! Establece una imagen de perfil y nombre completo para reconocerte más fácilmente entre todas las funcionalidades. ",
    "Add your profile information! Set a full name for easier recognition across all features." : "Agregua tu información de perfil! Establece tu nombre completo para reconocerte más fácilmente entre todas las funcionalidades. ",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Agrega tu información de perfil! Establece una imagen de perfil para reconocerte más fácilmente entre todas las funcionalidades. ",
    "Get the apps to sync your files" : "Obten las aplicaciones para sincronizar tus archivos",
    "Desktop client" : "Cliente de escritorio",
    "Android app" : "Aplicación Android",
    "iOS app" : "Aplicación iOS",
    "Connect your desktop apps to %s" : "Conecta tu aplicación de escritorio a %s",
    "Connect your calendar" : "Conecta tu calendario",
    "Connect your contacts" : "Conecta tus contactos",
    "Access files via WebDAV" : "Accede tus archivos vía WebDAV",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Accede & comparte tus archivos, calendarios, contactos, correo & más desde cualquier dispositivo, en tus propios términos",
    "Connect your Calendar" : "Conecta tu Calendario",
    "Connect your Contacts" : "Conecta a tus Contactos",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "Puedes encontrar más información en la <a target=\"_blank\" href=\"%s\">documentación</a> y en nuestro <a target=\"_blank\" href=\"%s\">sitio web</a>.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "Si te agrada NextCloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud es un gran software abierto para sincronizar y compartir sus archivos. Puede obtenerlo de forma gratuita desde https://nextcloud.com\"> recomiéndalo a tus amigos</a> y <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribuye</a>!",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "Si deseas soportar el proyecto ¡{contributeopen}únete al desarrollo{linkclose} o {contributeopen}pasa la voz{linkclose}!",
    "Show First Run Wizard again" : "Mostrar el Asistente de Ejecución Inicial de nuevo"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/es_PR.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "Copy to clipboard" : "Copiar al portapapeles",
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
    "First run wizard" : "Asistente de Ejecución Inicial",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "¡Agregua tu información de perfil! Establece una imagen de perfil y nombre completo para reconocerte más fácilmente entre todas las funcionalidades. ",
    "Add your profile information! Set a full name for easier recognition across all features." : "Agregua tu información de perfil! Establece tu nombre completo para reconocerte más fácilmente entre todas las funcionalidades. ",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Agrega tu información de perfil! Establece una imagen de perfil para reconocerte más fácilmente entre todas las funcionalidades. ",
    "About" : "Acerca",
    "Get the apps to sync your files" : "Obten las aplicaciones para sincronizar tus archivos",
    "Desktop client" : "Cliente de escritorio",
    "iOS app" : "Aplicación iOS",
    "Connect your desktop apps to %s" : "Conecta tu aplicación de escritorio a %s",
    "Connect your calendar" : "Conecta tu calendario",
    "Connect your contacts" : "Conecta tus contactos",
    "Access files via WebDAV" : "Accede tus archivos vía WebDAV",
    "A safe home for all your data" : "Un lugar seguro para todos sus datos",
    "Server address" : "Dirección del servidor",
    "Copy link" : "Copiar liga",
    "Android app" : "Aplicación Android"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
